@@ -42,9 +42,9 @@ class FastTrackerConfiger:
         :return:
         """
         if not config_file:
-            print("FAST:没有探针配置文件")
-            raise exceptions.ConfigurationError("没有发现配置文件")
-        print("FAST:探针的配置文件是 %s" % config_file)
+            functions.log("没有探针配置文件")
+            return False
+        functions.log("探针配置文件: %r", config_file)
 
         try:
             with open(config_file, "r") as fb:
@@ -70,7 +70,7 @@ class FastTrackerConfiger:
                                 getattr(config, func_name)(config_dict.get(config_key))
 
         except Exception as e:
-            raise exceptions.ConfigurationError("json格式配置文件格式不合法(不要有注释),解析失败,文件: %s, 错误信息：%s" % (config_file, str(e)))
+            functions.log("python探针初始化失败！json格式配置文件格式不合法(不要有注释),解析失败,文件: %s, 错误信息：%s", config_file, str(e))
 
     @staticmethod
     def set_config_by_env():
@@ -97,6 +97,8 @@ class FastTrackerConfiger:
                     setattr(config, "collector_address", val)
                 elif key == "FastTracker_Logging_Level":
                     setattr(config, "logging_level", val.upper())
+                elif key == "FastTracker_Debug_Level":
+                    setattr(config, "debug_level", int(val))
                 else:
                     config_name = functions.lower_case_name(key[12:])
                     setattr(config, config_name, val)
